TileKey class
Identifies a slippy-map tile by zoom and grid position.
x is always normalized to 0 <= x < 2^z (the world wraps in
longitude); y is expected to be within 0 <= y < 2^z.
- Annotations
Constructors
Properties
Methods
-
ancestorAt(
int ancestorZoom) → TileKey -
The ancestor of this tile at
ancestorZoom, which must be<= z. -
fractionOf(
TileKey ancestor) → ({double dx, double dy, double scale}) -
This tile's position within its ancestor at
ancestorZoom, in fractional tile units of the ancestor (0..1 origin, size2^-shift). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override